from django.conf.urls import include, url
from django.views.generic import TemplateView


urlpatterns = [
    url(r"^", include("pinax.comments.urls")),
    url(r"^demo/$", TemplateView.as_view(), name="demo_detail"),
]



from django.conf.urls import url

from . import views


urlpatterns = [
    url(r"^comment/(?P<content_type_id>\d+)/(?P<object_id>\d+)/$", views.post_comment,
        name="post_comment"),
    url(r"^comment/(?P<comment_id>\d+)/delete/$", views.delete_comment,
        name="delete_comment"),
    url(r"^comment/(?P<comment_id>\d+)/edit/$", views.edit_comment,
        name="edit_comment"),
]



from django.core.urlresolvers import reverse
from django.db import models


class Demo(models.Model):
    name = models.CharField(max_length=10)

    def get_absolute_url(self):
        return reverse("demo_detail")
